@@ -8,6 +8,7 @@ from .seq import Seq
 from .tuple import Tuple
 from .dicts import Dict
 from .map import Map
+from .sets import *
 from .attributes import Attr 
 
 
@@ -29,3 +30,5 @@ else:
 
 from .extensions import (identifier_expression, identifier_contract,
                          Extension, CheckCallable)
+
+from .isinstance_imp import *
